Class: ActiveSupport::TaggedLogging
- Inherits:
-
Object
- Object
- ActiveSupport::TaggedLogging
- Defined in:
- lib/logjam_agent/buffered_logger.rb
Overview
monkey patch to handle exceptions correctly not needed for rails 4 as this uses a Formatter to add the tags
Instance Method Summary collapse
-
#initialize(logger) ⇒ TaggedLogging
constructor
A new instance of TaggedLogging.
Constructor Details
#initialize(logger) ⇒ TaggedLogging
Returns a new instance of TaggedLogging.
11 12 13 14 15 16 17 18 19 20 |
# File 'lib/logjam_agent/buffered_logger.rb', line 11 def initialize(logger) @logger = logger if logger.is_a?(LogjamAgent::BufferedLogger) self.class.class_eval " def add(severity, message = nil, progname = nil, &block)\n @logger.add(severity, message, progname, tags_text, &block)\n end\n EVAL\n end\nend\n", __FILE__, __LINE__ + 1 |